import type { Logger } from 'winston';
import { createLog } from '../log'
import { Shell } from '../shell';
import { delay } from '../delay';
import { EOL } from 'os';

export class FFMPEG {
	private bin : string;
	private log : Logger;
	private shell : Shell;
	private formats : string[] = [];
	private formatsInfo : any = {};

	constructor (bin: string = 'ffmpeg') {
		this.bin = bin;
		this.log = createLog('ffmpeg');
	}

	private async rawList () : Promise<string> {
		const cmd : string[] = [ this.bin, '-formats' ];
		return new Promise(async (resolve : Function, reject : Function) => {
			this.shell = new Shell(cmd, null, null, resolve, true);
			await this.shell.execute();
		});
	}

	private async demuxerInfo (demuxer : string) : Promise<string> {
		const cmd : string[] = [ this.bin, `ffmpeg -h demuxer=${demuxer}` ];
		return new Promise(async (resolve : Function, reject : Function) => {
			this.shell = new Shell(cmd, null, null, resolve, true);
			await this.shell.execute();
		});
	}

	async listFormats () : Promise<string[]> {
		
		let list : string = null;
		let rows : string[];
		let key : string;
		let description : string;
		let info : string;

		this.formats = [];
		this.formatsInfo = {};

		try {
			list = await this.rawList();
		} catch (err) {
			this.log.error('Error listing formats', err);
		}

		if (list !== null) {
			rows = list.split(EOL);
			for (let row of rows) {
				//this.log.info(`"${row}"`);
				if (row.startsWith(' DE ')) {
					key = row.substring(4, row.length - 1).split(' ')[0];
					description = row.replace(key, '').trim();
					//this.log.info(key);
					/*try {
						this.log.info(await this.demuxerInfo(key));
					} catch (err) {
						this.log.error(err);
					}*/
					this.formats.push(key);
					this.formatsInfo[key] = {
						description
					};
				} else if (row.startsWith(' D  ')) {
					key = row.substring(4, row.length - 1).split(' ')[0];
					description = row.replace(key, '').trim();
					//this.log.info(key);
					/*try {
						this.log.info(await this.demuxerInfo(key));
					} catch (err) {
						this.log.error(err);
					}*/
					this.formats.push(key);
					this.formatsInfo[key] = {
						description
					};
				}
			}
		}

		return this.formats;
	}
}

module.exports = { FFMPEG };